==> fawaterak-online-payment-0.1.3.tgz: package/README.md <==
# fawaterak-online-payment

integrate with fawaterk online payment

## Installation

```sh
npm install fawaterak-online-payment
```

## Usage

```js
import { createInvoiceRequest, getInvoicePaymentTypes } from 'fawaterak-online-payment';

type PATMENT_TYPE = {
  paymentId: number;
  paymentCode: string;
  paymentMethod: string;
  paymentMethodData: PAYMENT_METHOD_DATA;
};

export default function App() {

  const [paymentTypes, setPaymentTypes] = React.useState<Array<PATMENT_TYPE>>(
    []
  );

  const [paymentMethodId, setPaymentMethodId] = React.useState<number>(0);

  React.useEffect(() => {
    // gel all payment type
    getInvoicePaymentTypes('USER_TOKEN_KEY').then((res) => {
      setPaymentTypes(res as PATMENT_TYPE[]);
    });
  }, []);

    const saveSelectedPaymentType = async () => {
    let request = {
      payment_method_id: paymentMethodId, // paymentId
      cartTotal: 10,
      currency: 'EGP',
      customer: {
        first_name: 'FIRST NAME',
        last_name: 'LAST NAME',
        email: 'Test@email.com',
        phone: '010xxxxxxxx',
        address: 'ADDRESS',
      },
      cartItems: [
        {
          name: 'PRODUCT NAME',
          price: 10,
          quantity: 1,
        },
      ],
    };

    let apiPath = '';
    switch (paymentMethodId) {
      case 3: // Fawry paymentId
        apiPath = '/invoiceInitPay';
        request = {
          ...request,
          payment_method_id: paymentMethodId,
        };
        break;
      case 4: // MobileWallets paymentId
        apiPath = '/invoiceInitPay';
        request = {
          ...request,
          payment_method_id: paymentMethodId,
        };
        break;
      case 0: // Payment Link paymentId
        apiPath = '/createInvoiceLink';
        request = {
          ...request,
          payment_method_id: paymentMethodId,
        };
        break;
    }
    await createInvoiceRequest(apiPath, request);
  };

  return (
    <>
    // your code here...
    </>
  );
}
```

==> fawaterak-online-payment-0.1.4.tgz: package/README.md <==
# fawaterak-online-payment

integrate with fawaterk online payment

## Installation

```sh
npm install fawaterak-online-payment
```

## Usage

```js
import { createInvoiceRequest, getInvoicePaymentTypes } from 'fawaterak-online-payment';

type PATMENT_TYPE = {
  paymentId: number;
  paymentCode: string;
  paymentMethod: string;
  paymentMethodData: PAYMENT_METHOD_DATA;
};

export default function App() {

  const [paymentTypes, setPaymentTypes] = React.useState<Array<PATMENT_TYPE>>(
    []
  );

  const [paymentMethodId, setPaymentMethodId] = React.useState<number>(0);

  React.useEffect(() => {
    // get all payment type
    getInvoicePaymentTypes('USER_TOKEN_KEY').then((res) => {
      setPaymentTypes(res as PATMENT_TYPE[]);
    });
  }, []);

  // create your invoice
  const saveSelectedPaymentType = async () => {
    let request = {
      payment_method_id: paymentMethodId, // paymentId
      cartTotal: 10,
      currency: 'EGP',
      customer: {
        first_name: 'FIRST NAME',
        last_name: 'LAST NAME',
        email: 'Test@email.com',
        phone: '01011111111',
        address: 'ADDRESS',
      },
      cartItems: [
        {
          name: 'PRODUCT NAME',
          price: 10,
          quantity: 1,
        },
      ],
    };

    let apiPath = '';
    switch (paymentMethodId) {
      case 3: // Fawry paymentId
        apiPath = '/invoiceInitPay';
        request = {
          ...request,
          payment_method_id: paymentMethodId,
        };
        break;
      case 4: // MobileWallets paymentId
        apiPath = '/invoiceInitPay';
        request = {
          ...request,
          payment_method_id: paymentMethodId,
        };
        break;
      case 0: // Payment Link paymentId
        apiPath = '/createInvoiceLink';
        request = {
          ...request,
          payment_method_id: paymentMethodId,
        };
        break;
    }
    await createInvoiceRequest(apiPath, request);
  };

  return (
    <>
    // your code here...
    </>
  );
}
```
